@@ -21,8 +21,8 @@ which mate-autogen || {
 }
 
 which yelp-build || {
-    echo "You need to install yelp-tools" 
+    echo "You need to install yelp-tools"
     exit 1
 }
 
-USE_MATE2_MACROS=1 USE_COMMON_DOC_BUILD=yes . mate-autogen
+USE_COMMON_DOC_BUILD=yes . mate-autogen
