@@ -29,7 +29,6 @@ struct UnitPrivate
 
 G_DEFINE_TYPE_WITH_PRIVATE (Unit, unit, G_TYPE_OBJECT);
 
-
 Unit *
 unit_new(const gchar *name,
          const gchar *display_name,
@@ -49,13 +48,12 @@ unit_new(const gchar *name,
     unit->priv->to_function = g_strdup(to_function);
     symbol_names = g_strsplit(symbols, ",", 0);
     for (i = 0; symbol_names[i]; i++)
-        unit->priv->symbols = g_list_append(unit->priv->symbols, g_strdup(symbol_names[i]));
+        unit->priv->symbols = g_list_append(unit->priv->symbols, symbol_names[i]);
     g_free(symbol_names);
 
     return unit;
 }
 
-
 const gchar *
 unit_get_name(Unit *unit)
 {
@@ -63,7 +61,6 @@ unit_get_name(Unit *unit)
     return unit->priv->name;
 }
 
-
 const gchar *
 unit_get_display_name(Unit *unit)
 {
@@ -71,7 +68,6 @@ unit_get_display_name(Unit *unit)
     return unit->priv->display_name;
 }
 
-
 gboolean
 unit_matches_symbol(Unit *unit, const gchar *symbol)
 {
@@ -89,7 +85,6 @@ unit_matches_symbol(Unit *unit, const gchar *symbol)
     return FALSE;
 }
 
-
 const GList *
 unit_get_symbols(Unit *unit)
 {
@@ -97,14 +92,12 @@ unit_get_symbols(Unit *unit)
     return unit->priv->symbols;
 }
 
-
 static int
 variable_is_defined(const char *name, void *data)
 {
     return TRUE;
 }
 
-
 static int
 get_variable(const char *name, MPNumber *z, void *data)
 {
@@ -113,7 +106,6 @@ get_variable(const char *name, MPNumber *z, void *data)
     return TRUE;
 }
 
-
 static gboolean
 solve_function(const gchar *function, const MPNumber *x, MPNumber *z)
 {
@@ -135,7 +127,6 @@ solve_function(const gchar *function, const MPNumber *x, MPNumber *z)
     return TRUE;
 }
 
-
 gboolean
 unit_convert_from(Unit *unit, const MPNumber *x, MPNumber *z)
 {
@@ -157,7 +148,6 @@ unit_convert_from(Unit *unit, const MPNumber *x, MPNumber *z)
     }
 }
 
-
 gboolean
 unit_convert_to(Unit *unit, const MPNumber *x, MPNumber *z)
 {
@@ -179,7 +169,6 @@ unit_convert_to(Unit *unit, const MPNumber *x, MPNumber *z)
     }
 }
 
-
 gchar *
 unit_format(Unit *unit, MPNumber *x)
 {
@@ -195,13 +184,11 @@ unit_format(Unit *unit, MPNumber *x)
     return text;
 }
 
-
 static void
 unit_class_init(UnitClass *klass)
 {
 }
 
-
 static void
 unit_init(Unit *unit)
 {
